/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.ws.rm.policy;

import jakarta.jws.WebMethod;
import jakarta.jws.WebParam;
import jakarta.jws.WebService;

@WebService(targetNamespace = "http://ws.samples.apache.org/",
            serviceName = "GreetingService", portName = "GreetingServicePort",
            wsdlLocation = "classpath:/org/apache/cxf/systest/ws/rm/policy/greeting.wsdl")
public class GreetingService implements Greeting {

    @WebMethod
    public String hello(@WebParam(name = "name") String name) {
        return String.format("Hello, %s!", name);
    }

    @WebMethod
    public String goodbye(@WebParam(name = "name") String name) {
        return String.format("Goodbye, %s!", name);
    }

}
